# soak
Process aridity templates en masse, like Helm but much more DRY

## Advantages
* Single sourcing of config i.e. DRY
* No need for all of your team to know Helm's many conventions
* Terraform native customisation is limited and verbose, and the override mechanism is another convention
* Multiple instances of your microservice without hacks
* Extensible via Python code

## Commands

### soak
Process aridity templates as per all soak.arid configs in directory tree.

## API

<a id="soak.context"></a>

### soak.context

<a id="soak.util"></a>

### soak.util

